import * as i0 from '@angular/core';
import { NgModule, Injectable } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as i3 from '@annuadvent/ngx-tools/fire-store';
import { StructuredQueryOperatorEnum, StructuredQueryValueType } from '@annuadvent/ngx-tools/fire-store';
import * as i1 from '@annuadvent/ngx-tools/fire-common';
import * as i2 from '@annuadvent/ngx-core/utils';

class FireCmsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCmsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: FireCmsModule, imports: [CommonModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCmsModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCmsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    providers: [],
                    imports: [
                        CommonModule
                    ]
                }]
        }] });

const ARTICLES_COLLECTION_ID = 'articles';
const SHALLOW_ARTICLE_FIELDS = [
    'metaInfo',
    'image',
    'categories',
    'created',
    'updated',
    'userId',
    'isLive',
    "inReview",
    "features",
];
const UPDATE_ARTICLE_FIELDS = [
    'metaInfo',
    'image',
    'categories',
    'created',
    'updated',
    'userId',
    "inReview",
    "features",
    "body",
];

const CATEGORIES_COLLECTION_ID = 'categories';
const SHALLOW_CATEGORY_FIELDS = [
    "shortTitle",
    "isFeatured",
    "metaInfo",
    "image",
    "created",
    "updated",
    "userId",
    "isLive",
    "inReview",
    "features",
];
const UPDATE_CATEGORY_FIELDS = [
    "shortTitle",
    "isFeatured",
    "metaInfo",
    "image",
    'created',
    "updated",
    "userId",
    "inReview",
    "features",
];

;

;
;

;

class FireArticlesHttpService {
    constructor(fireCommonService, utilsSvc, firestoreHttpService) {
        this.fireCommonService = fireCommonService;
        this.utilsSvc = utilsSvc;
        this.firestoreHttpService = firestoreHttpService;
        this.firestoreApiUrl = '';
        this.firestoreApiUrl = this.fireCommonService.firebaseConfig.store.firestoreBaseApiUrl;
    }
    async buildPageOfArticles(articles, pageSize = 0) {
        const articlesCount = articles?.length || 0;
        const pageArticles = {
            articles: articles || [],
            startPage: articlesCount ? articles[0]?.updated : null,
            endPage: articlesCount && pageSize && articlesCount === pageSize
                ? articles[articlesCount - 1]?.updated
                : null,
        };
        return pageArticles;
    }
    async getArticle(articleId) {
        try {
            const article = await this.firestoreHttpService.runQueryById(ARTICLES_COLLECTION_ID, articleId);
            return article;
        }
        catch (error) {
            throw error;
        }
    }
    async getLiveArticle(articleId) {
        if (!articleId)
            throw new Error('Please provide a valid article id.');
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'id',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: articleId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            const article = articles?.length ? articles[0] : null;
            return article;
        }
        catch (error) {
            throw error;
        }
    }
    async getUsersArticle(articleId, userId) {
        if (!articleId)
            throw new Error('Please provide a valid article id.');
        if (!userId)
            throw new Error('Please provide a valid article id.');
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'id',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: articleId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'userId',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: userId,
                    valueType: StructuredQueryValueType.stringValue
                },
            ],
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            const article = articles?.length ? articles[0] : null;
            return article;
        }
        catch (error) {
            throw error;
        }
    }
    async getUsersOnePageShallowArticles(userId, isLive, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'userId',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: userId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_ARTICLE_FIELDS,
            pageSize,
            isForwardDir,
            startPage: [startPage]
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfArticles(articles, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getAllUsersOnePageShallowArticles(isLive, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_ARTICLE_FIELDS,
            pageSize,
            isForwardDir,
            startPage: [startPage]
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfArticles(articles, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getUsersOnePageInReviewShallowArticles(userId, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'userId',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: userId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: null,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_ARTICLE_FIELDS,
            pageSize,
            isForwardDir,
            startPage: [startPage]
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfArticles(articles, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getAllUsersOnePageInReviewShallowArticles(pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: null,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_ARTICLE_FIELDS,
            pageSize,
            isForwardDir,
            startPage: [startPage]
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfArticles(articles, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getLiveShallowArticlesOfCategories(categories, pageSize = 0, startPage = null, isForwardDir = true) {
        let pageCategoryGroups = [];
        if (categories && categories.length) {
            const fireQuery = {
                collectionId: ARTICLES_COLLECTION_ID,
                where: [
                    {
                        fieldPath: 'isLive',
                        operator: StructuredQueryOperatorEnum.EQUAL,
                        value: true,
                        valueType: StructuredQueryValueType.booleanValue
                    },
                    {
                        fieldPath: 'categories',
                        operator: StructuredQueryOperatorEnum.ARRAY_CONTAINS,
                        value: '',
                        valueType: StructuredQueryValueType.stringValue
                    },
                ],
                orderBy: [
                    {
                        fieldPath: 'updated',
                        fieldType: StructuredQueryValueType.stringValue,
                        isDesc: true
                    }
                ],
                selectFields: SHALLOW_ARTICLE_FIELDS,
                pageSize,
                isForwardDir,
                startPage: [startPage]
            };
            try {
                pageCategoryGroups = await Promise.all(categories.map(async (cat) => {
                    const catId = typeof cat === 'string' ? cat : cat.id;
                    fireQuery.where.find(wh => wh.fieldPath === 'categories').value = catId;
                    try {
                        const catArticles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
                        // if a single category, then add pagearticles with previous and next page info else leave that info empty., so that pagination can be enebled for Category articles.
                        let pageArticles = await this.buildPageOfArticles(catArticles, pageSize);
                        const pageCategoryGroup = {
                            category: typeof cat === 'string' ? { id: cat } : cat,
                            pageArticles,
                        };
                        return pageCategoryGroup;
                    }
                    catch (error) {
                        throw error;
                    }
                }));
            }
            catch (error) {
                throw error;
            }
        }
        return pageCategoryGroups;
    }
    async getAllLiveArticlesFromDate(fromDateTime) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'updated',
                    operator: StructuredQueryOperatorEnum.GREATER_THAN_OR_EQUAL,
                    value: fromDateTime,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: ['categories', 'updated'],
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return articles;
        }
        catch (error) {
            throw error;
        }
    }
    async getLiveOnePageShallowArticlesByFeatures(features, isLive = true, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: ARTICLES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'features',
                    operator: StructuredQueryOperatorEnum.ARRAY_CONTAINS_ANY,
                    value: features,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_ARTICLE_FIELDS,
            pageSize,
            isForwardDir,
            startPage: [startPage]
        };
        try {
            const articles = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfArticles(articles, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async addArticle(article) {
        const existedArticle = await this.getArticle(article.id).catch((error) => {
            if (error.status === 404) {
                return null;
            }
            else {
                throw error;
            }
        });
        if (existedArticle)
            throw new Error('Article already Exist.');
        return this.updateArticle(article).catch((error) => {
            throw error;
        });
    }
    async updateArticle(article) {
        const fieldsToUpdate = [...UPDATE_ARTICLE_FIELDS, 'isLive'];
        const currentDate = this.utilsSvc.currentDate;
        const pArticle = { ...article, updated: currentDate, isLive: false, inReview: false };
        pArticle.metaInfo['article:published_time'] = currentDate;
        if (!pArticle.created)
            pArticle.created = currentDate;
        if (!pArticle.userId)
            throw new Error('Article userId is required.');
        return this.firestoreHttpService.runQueryToUpdate(ARTICLES_COLLECTION_ID, article, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async setArticleUpForReview(article) {
        const fieldsToUpdate = ['inReview', 'isLive', 'updated', 'metaInfo'];
        // Any modification to a article, will bring it to unpublished, and not up for review.
        article.isLive = article.inReview === true ? false : article.isLive;
        const currentDate = this.utilsSvc.currentDate;
        article.updated = currentDate;
        article.metaInfo['article:published_time'] = currentDate;
        return this.firestoreHttpService.runQueryToUpdate(ARTICLES_COLLECTION_ID, article, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async setArticleLive(article) {
        const fieldsToUpdate = ['inReview', 'isLive', 'updated', 'metaInfo'];
        // Any modification to a article, will bring it to unpublished, and not up for review.
        article.inReview = article.isLive === true ? false : article.inReview;
        const currentDate = this.utilsSvc.currentDate;
        article.updated = currentDate;
        article.metaInfo['article:published_time'] = currentDate;
        return this.firestoreHttpService.runQueryToUpdate(ARTICLES_COLLECTION_ID, article, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async deleteArticle(article) {
        return this.firestoreHttpService.runQueryToDelete(ARTICLES_COLLECTION_ID, article);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireArticlesHttpService, deps: [{ token: i1.FireCommonService }, { token: i2.UtilsService }, { token: i3.FirestoreHttpService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireArticlesHttpService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireArticlesHttpService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }, { type: i2.UtilsService }, { type: i3.FirestoreHttpService }]; } });

class FireCategoriesHttpService {
    constructor(fireCommonService, utilsSvc, firestoreHttpService, fireArticlesHttpService) {
        this.fireCommonService = fireCommonService;
        this.utilsSvc = utilsSvc;
        this.firestoreHttpService = firestoreHttpService;
        this.fireArticlesHttpService = fireArticlesHttpService;
        this.firestoreApiUrl = '';
        this.firestoreApiUrl = this.fireCommonService.firebaseConfig.store.firestoreBaseApiUrl;
    }
    async buildPageOfCategories(categories, pageSize = 0) {
        const categoriesCount = categories?.length || 0;
        const pageCategories = {
            categories: categories || [],
            startPage: categoriesCount ? categories[0]?.updated : null,
            endPage: categoriesCount && pageSize && categoriesCount === pageSize
                ? categories[categoriesCount - 1]?.updated
                : null,
        };
        return pageCategories;
    }
    async getCategory(categoryId) {
        try {
            const category = await this.firestoreHttpService.runQueryById(CATEGORIES_COLLECTION_ID, categoryId);
            return category;
        }
        catch (error) {
            throw error;
        }
    }
    async getUsersCategory(userId, categoryId) {
        if (!userId)
            throw new Error('Please provide a valid user id.');
        if (!categoryId)
            throw new Error('Please Provide a valid category id.');
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'id',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: categoryId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'userId',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: userId,
                    valueType: StructuredQueryValueType.stringValue
                }
            ]
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            const category = (categories?.length && categories[0]) || null;
            return category;
        }
        catch (error) {
            throw error;
        }
    }
    async getAllLiveShallowCategories(isLive = true) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return categories;
        }
        catch (error) {
            throw error;
        }
    }
    async getAllLiveCategoriesWithOnePageShallowArticles(pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.fireArticlesHttpService.getLiveShallowArticlesOfCategories(categories, pageSize, startPage, isForwardDir);
        }
        catch (error) {
            throw error;
        }
    }
    async getLiveCategoryWithOnePageShallowArticles(categoryId, pageSize = 0, startPage = null, isForwardDir = true) {
        if (!categoryId)
            throw new Error('Please provide a valid category id.');
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'id',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: categoryId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            const category = (categories?.length && categories[0]) || null;
            if (category) {
                const pageCategoryGroups = await this.fireArticlesHttpService.getLiveShallowArticlesOfCategories([category], pageSize, startPage, isForwardDir);
                return (pageCategoryGroups?.length && pageCategoryGroups[0]) || null;
            }
            return null;
        }
        catch (error) {
            throw error;
        }
    }
    async getUsersOnePageShallowCategories(userId, isLive, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'userId',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: userId,
                    valueType: StructuredQueryValueType.stringValue
                },
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfCategories(categories, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getAllUsersOnePageShallowCategories(isLive, pageSize = 0, startPage = null, isForwardDir = true) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
            pageSize,
            isForwardDir,
            startPage: startPage ? [startPage] : null
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return await this.buildPageOfCategories(categories, pageSize);
        }
        catch (error) {
            throw error;
        }
    }
    async getShallowCategoriesByIds(categoryIds) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'id',
                    operator: StructuredQueryOperatorEnum.IN,
                    value: categoryIds,
                    valueType: StructuredQueryValueType.stringValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            return await this.firestoreHttpService.runQueryByConfig(fireQuery);
        }
        catch (error) {
            throw error;
        }
    }
    async getShallowLiveCategoriesByFeatures(features, isLive = true) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: isLive,
                    valueType: StructuredQueryValueType.booleanValue
                },
                {
                    fieldPath: 'features',
                    operator: features instanceof Array ?
                        StructuredQueryOperatorEnum.ARRAY_CONTAINS_ANY :
                        StructuredQueryOperatorEnum.ARRAY_CONTAINS,
                    value: features,
                    valueType: StructuredQueryValueType.stringValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: SHALLOW_CATEGORY_FIELDS,
        };
        try {
            return await this.firestoreHttpService.runQueryByConfig(fireQuery);
        }
        catch (error) {
            throw error;
        }
    }
    /**
     * Get all Live categories since the given last updated, by date.
     * @date 2/27/2023 - 6:40:21 PM
     *
     * @public
     * @async
     * @param {string} fromDateTime
     * @returns {Promise<Array<Category>>}
     */
    async getAllLiveCategoriesFromDate(fromDateTime) {
        const fireQuery = {
            collectionId: CATEGORIES_COLLECTION_ID,
            where: [
                {
                    fieldPath: 'isLive',
                    operator: StructuredQueryOperatorEnum.EQUAL,
                    value: true,
                    valueType: StructuredQueryValueType.booleanValue
                },
                {
                    fieldPath: 'updated',
                    operator: StructuredQueryOperatorEnum.GREATER_THAN_OR_EQUAL,
                    value: fromDateTime,
                    valueType: StructuredQueryValueType.stringValue
                },
            ],
            orderBy: [
                {
                    fieldPath: 'updated',
                    fieldType: StructuredQueryValueType.stringValue,
                    isDesc: true
                }
            ],
            selectFields: ['updated'],
        };
        try {
            const categories = await this.firestoreHttpService.runQueryByConfig(fireQuery);
            return categories;
        }
        catch (error) {
            throw error;
        }
    }
    async addCategory(category) {
        const existedCategory = await this.getCategory(category.id).catch((error) => {
            if (error.status === 404) {
                return null;
            }
            else {
                throw error;
            }
        });
        if (existedCategory)
            throw new Error('Category already Exist.');
        return this.updateCategory(category)
            .catch((error) => {
            throw error;
        });
    }
    async updateCategory(category) {
        const fieldsToUpdate = [...UPDATE_CATEGORY_FIELDS, 'isLive'];
        // Any modification to a category, will bring it to unpublished, and not up for review.
        const currentDate = this.utilsSvc.currentDate;
        const pCategory = { ...category, updated: currentDate, isLive: false, inReview: false };
        pCategory.metaInfo['article:published_time'] = currentDate;
        if (!pCategory.created)
            pCategory.created = currentDate;
        if (!pCategory.userId)
            throw new Error('Category userId is required.');
        return this.firestoreHttpService.runQueryToUpdate(CATEGORIES_COLLECTION_ID, pCategory, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async setCategoryUpForReview(category) {
        const fieldsToUpdate = ['inReview', 'isLive', 'updated', 'metaInfo'];
        // Any modification to a category, will bring it to unpublished, and not up for review.
        category.isLive = category.inReview === true ? false : category.isLive;
        return this.firestoreHttpService.runQueryToUpdate(CATEGORIES_COLLECTION_ID, category, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async setCategoryLive(category) {
        const fieldsToUpdate = ['inReview', 'isLive', 'updated', 'metaInfo'];
        // Any modification to a category, will bring it to unpublished, and not up for review.
        category.inReview = category.isLive === true ? false : category.inReview;
        return this.firestoreHttpService.runQueryToUpdate(CATEGORIES_COLLECTION_ID, category, fieldsToUpdate, false)
            .catch((error) => {
            throw error;
        });
    }
    async deleteCategory(category) {
        return this.firestoreHttpService.runQueryToDelete(CATEGORIES_COLLECTION_ID, category);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCategoriesHttpService, deps: [{ token: i1.FireCommonService }, { token: i2.UtilsService }, { token: i3.FirestoreHttpService }, { token: FireArticlesHttpService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCategoriesHttpService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireCategoriesHttpService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }, { type: i2.UtilsService }, { type: i3.FirestoreHttpService }, { type: FireArticlesHttpService }]; } });

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { ARTICLES_COLLECTION_ID, CATEGORIES_COLLECTION_ID, FireArticlesHttpService, FireCategoriesHttpService, FireCmsModule, SHALLOW_ARTICLE_FIELDS, SHALLOW_CATEGORY_FIELDS, UPDATE_ARTICLE_FIELDS, UPDATE_CATEGORY_FIELDS };
//# sourceMappingURL=annuadvent-ngx-tools-fire-cms.mjs.map
