import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import * as i3$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from '@annuadvent/ngx-common-ui/card';
import { CardModule } from '@annuadvent/ngx-common-ui/card';
import * as i5 from '@annuadvent/ngx-common-ui/collapsible';
import { CollapsibleModule } from '@annuadvent/ngx-common-ui/collapsible';
import * as i6 from '@annuadvent/ngx-common-ui/code-block';
import { CodeBlockModule } from '@annuadvent/ngx-common-ui/code-block';
import * as i7 from '@annuadvent/ngx-common-ui/modal';
import { ModalModule } from '@annuadvent/ngx-common-ui/modal';
import * as i2 from '@annuadvent/ngx-core/utils';
import { catchError, throwError } from 'rxjs';
import { Buffer } from 'buffer';
import { json2xml, xml2json } from 'xml-js';
import * as i1$1 from '@annuadvent/ngx-core/app-config';
import * as i3 from '@angular/common/http';
import { getStorage, ref, uploadString, getDownloadURL, uploadBytes, deleteObject, list } from 'firebase/storage';
import * as i1 from '@annuadvent/ngx-tools/fire-common';
import Compressor from 'compressorjs';

const sitemapFileName = 'sitemap.xml';
const defaultSitemapXmlStr = `
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://www.sitemaps.org/schemas/sitemap/0.9 http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd">
</urlset>
`;

class FireStorageSitemapService {
    constructor(fireCommonService) {
        this.fireCommonService = fireCommonService;
        this.sitemapFileName = sitemapFileName;
    }
    async uploadSitemap(sitemapData) {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileRef = ref(fireStorage, this.sitemapFileName);
        try {
            const uploadResult = await uploadString(fileRef, sitemapData);
            return true;
        }
        catch (error) {
            throw error;
        }
    }
    async sitemapExists() {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileRef = ref(fireStorage, this.sitemapFileName);
        try {
            const url = await getDownloadURL(fileRef);
            return url;
        }
        catch (error) {
            if (error.code !== 'storage/object-not-found') {
                throw error;
            }
            else {
                return '';
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, deps: [{ token: i1.FireCommonService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }]; } });

class SitemapService {
    constructor(appConfigService, utilsSvc, httpClient, sitemapFireSvc) {
        this.appConfigService = appConfigService;
        this.utilsSvc = utilsSvc;
        this.httpClient = httpClient;
        this.sitemapFireSvc = sitemapFireSvc;
        if (typeof window !== undefined) {
            window.Buffer = window.Buffer || Buffer;
        }
    }
    /**
     * Reads the sitemap.xml
     * @date 2/21/2023 - 11:35:49 PM
     *
     * @public
     * @async
     * @returns {Promise<SitemapResponse>}
     */
    async getSitemapResponse() {
        const sitemapDownloadUrl = await this.sitemapFireSvc.sitemapExists();
        let sitemapStr = '';
        if (sitemapDownloadUrl) {
            const xmlResponseObserver$ = this.httpClient.get(sitemapDownloadUrl, {
                observe: 'body',
                responseType: 'text' // hack to avoid type error
            });
            return new Promise((resolve, reject) => {
                xmlResponseObserver$.pipe(catchError((error) => {
                    reject(error);
                    return throwError(() => {
                        return error;
                    });
                }))
                    .subscribe((sitemapStr) => {
                    resolve(this.prepareSitemapResponse(sitemapStr));
                });
            });
        }
        else {
            sitemapStr = defaultSitemapXmlStr;
            return this.prepareSitemapResponse(sitemapStr);
        }
    }
    /**
     * Saves both sitemap.xml to firebase storage
     * @date 2/28/2023 - 11:13:44 PM
     *
     * @public
     * @async
     * @param {Sitemap} sitemapJson
     * @returns {Promise<boolean>}
     */
    async saveSitemap(sitemapJson) {
        const xmlStr = this.jsonToXmlSitemap(sitemapJson);
        const result = await this.sitemapFireSvc.uploadSitemap(xmlStr);
        return result;
    }
    /**
     * Appends Urls to existing sitemap json.
     * @date 2/22/2023 - 1:35:03 AM
     *
     * @public
     * @param {Array<SitemapItem>} urls
     * @param {Sitemap} sitemap
     * @returns {Sitemap}
     */
    addUrlsToSitemapJson(urls, sitemap) {
        const newSitemap = this.utilsSvc.deepCopy(sitemap);
        if (!urls || !urls.length) {
            return newSitemap;
        }
        const clonedUrls = urls.map(url => this.utilsSvc.deepCopy(url));
        clonedUrls.forEach(url => {
            // check if url exist in sitemap
            const index = newSitemap.urlset.url.findIndex(u => u.loc._text === url.loc._text);
            if (index >= 0) {
                url.status = false;
                newSitemap.urlset.url.splice(index, 1);
            }
            else {
                url.status = true;
            }
        });
        newSitemap.urlset.url = [].concat(newSitemap.urlset.url, clonedUrls);
        return newSitemap;
    }
    /**
     * Converts json sitemap to xml sitemap string.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {Sitemap} sitemap
     * @returns {string}
     */
    jsonToXmlSitemap(sitemap) {
        const sitemapStr = JSON.stringify(sitemap);
        const sitemapXmlStr = json2xml(sitemapStr, { compact: true, spaces: 4 });
        return sitemapXmlStr;
    }
    /**
     * Converts xml sitemap to json sitemap.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {xmlStr} string
     * @returns {Sitemap}
     */
    xmlToJsonSitemap(xmlStr = '') {
        //Unescaping \" to " so as to parse xml.
        const newStr = xmlStr.replaceAll('\\"', '"');
        const jsonStr = xml2json(newStr, { compact: true });
        const sitemap = JSON.parse(jsonStr);
        return sitemap;
    }
    getLastUpdatedFromSitemap(sitemap) {
        const urls = sitemap?.urlset?.url || [];
        let lastUpdated = '';
        if (!urls.length) {
            return (new Date('1979-01-01')).toISOString();
        }
        lastUpdated = urls[0].lastmod._text;
        urls.forEach(url => {
            if ((new Date(url.lastmod._text)) > (new Date(lastUpdated))) {
                lastUpdated = url.lastmod._text;
            }
        });
        return lastUpdated;
    }
    prepareSitemapResponse(sitemapStr) {
        const sitemap = this.xmlToJsonSitemap(sitemapStr);
        const sitemapInfo = {
            updated: this.getLastUpdatedFromSitemap(sitemap)
        };
        // check if no urls in xml then add root and login urls.
        if (!sitemap.urlset?.url?.length) {
            sitemap.urlset.url = [
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                },
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}/login`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                }
            ];
        }
        const sitemapResponse = {
            sitemapInfo,
            sitemap
        };
        return sitemapResponse;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, deps: [{ token: i1$1.AppConfigService }, { token: i2.UtilsService }, { token: i3.HttpClient }, { token: FireStorageSitemapService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.AppConfigService }, { type: i2.UtilsService }, { type: i3.HttpClient }, { type: FireStorageSitemapService }]; } });

class SitemapComponent {
    constructor(utilsSvc, sitemapService) {
        this.utilsSvc = utilsSvc;
        this.sitemapService = sitemapService;
        this.newUrls = [];
        this.loadSitemapClicked = new EventEmitter();
        this.saveClicked = new EventEmitter();
        this.previewClicked = new EventEmitter();
        this.checkNewUrlsClicked = new EventEmitter();
        this.currentSitemapCollapsed = false;
        this.checkNewUrlsCollapsed = false;
        this.previewCollapsed = false;
        this.newUrlsStatus = {};
        this.sitemapXmlStr = '';
        this.showXmlModal = false;
    }
    loadSitemap(event) {
        event.preventDefault();
        this.currentSitemapCollapsed = true;
        this.loadSitemapClicked.emit();
    }
    checkNewUrls(event) {
        event.preventDefault();
        this.checkNewUrlsCollapsed = true;
        this.checkNewUrlsClicked.emit();
    }
    previewSitemap(event) {
        event.preventDefault();
        this.previewCollapsed = true;
        this.previewClicked.emit();
    }
    saveSitemap(event) {
        event.preventDefault();
        const clonedNewSitemap = this.utilsSvc.deepCopy(this.newSitemap);
        clonedNewSitemap.urlset.url.forEach(url => {
            delete url.status;
        });
        this.saveClicked.emit(clonedNewSitemap);
    }
    showXmlString(event, sitemapJson) {
        event.preventDefault();
        this.sitemapXmlStr = this.sitemapService.jsonToXmlSitemap(sitemapJson);
        this.showXmlModal = true;
    }
    xmlModalClosed() {
        this.showXmlModal = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapComponent, deps: [{ token: i2.UtilsService }, { token: SitemapService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: SitemapComponent, selector: "anu-sitemap", inputs: { sitemap: "sitemap", sitemapInfo: "sitemapInfo", newUrls: "newUrls", newSitemap: "newSitemap" }, outputs: { loadSitemapClicked: "loadSitemapClicked", saveClicked: "saveClicked", previewClicked: "previewClicked", checkNewUrlsClicked: "checkNewUrlsClicked" }, ngImport: i0, template: "<div class=\"flex-container center\">\r\n    <div class=\"container\">\r\n        <div class=\"row\">\r\n            <!-- Current Sitemap Urls -->\r\n            <anu-card class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"loadSitemap($event)\">Load sitemap.xml</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible class=\"spacing-vertical\" *ngIf=\"sitemapInfo || sitemap\"\r\n                        [collapsed]=\"currentSitemapCollapsed\" [hamBurgerClassNames]=\"['size-md']\"\r\n                        [isDropdownStyle]=\"true\" (changed)=\"currentSitemapCollapsed = !currentSitemapCollapsed\">\r\n                        <anu-collapsible-header>Current Sitemap</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <h3 *ngIf=\"sitemapInfo\">Sitemap was last updated on:\r\n                                <strong>{{sitemapInfo.updated}}</strong>\r\n                            </h3>\r\n                            <ol *ngIf=\"sitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of sitemap.urlset.url\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, sitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n            <!-- New Urls to be added -->\r\n            <anu-card *ngIf=\"sitemap\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"checkNewUrls($event)\">Check for new Urls</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newUrls\" class=\"spacing-vertical\" [collapsed]=\"checkNewUrlsCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"checkNewUrlsCollapsed = !checkNewUrlsCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">Sitemap new Urls</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <ol *ngIf=\"newUrls?.length\">\r\n                                <li *ngFor=\"let url of newUrls\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <p *ngIf=\"!newUrls?.length\" class=\"warning\">No new urls available</p>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n\r\n            <!-- Preview Merged Urls -->\r\n            <anu-card *ngIf=\"newUrls?.length\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"previewSitemap($event)\">Preview sitemap.xml (Ready to update)</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newSitemap\" class=\"spacing-vertical\" [collapsed]=\"previewCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"previewCollapsed = !previewCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">New Sitemap (Ready to\r\n                            update)</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <div class=\"row\">\r\n                                <span class=\"spacing-half spacing-around\"><small><strong>LEGENDS:</strong>\r\n                                    </small></span>\r\n                                <span class=\"spacing-half spacing-around\"><small>No change</small></span>\r\n                                <span class=\"spacing-half spacing-around success\"><small>Added</small></span>\r\n                                <span class=\"spacing-half spacing-around warning\"><small>Updated</small></span>\r\n                            </div>\r\n                            <ol *ngIf=\"newSitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of newSitemap.urlset.url\" [class.success]=\"url.status === true\"\r\n                                    [class.warning]=\"url.status === false\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, newSitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n                <anu-card-footer *ngIf=\"newSitemap\">\r\n                    <a href=\"#\" class=\"btn btn-primary\" (click)=\"saveSitemap($event)\">Save</a>\r\n                </anu-card-footer>\r\n            </anu-card>\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n<anu-modal [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"false\" [okLabel]=\"'Ok'\"\r\n    [opened]=\"showXmlModal\" [title]=\"'XML view of sitemap'\" (cancelClick)=\"xmlModalClosed()\">\r\n\r\n    <anu-code-block class=\"col-12\" [enableEdit]='false' [language]=\"'xml'\" [source]=\"sitemapXmlStr\">\r\n    </anu-code-block>\r\n\r\n</anu-modal>\r\n", styles: [""], dependencies: [{ kind: "directive", type: i3$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i4.CardComponent, selector: "anu-card", inputs: ["isRowLayout", "imageCssClasses", "contentCssClasses"] }, { kind: "component", type: i4.CardTitleComponent, selector: "anu-card-title" }, { kind: "component", type: i4.CardBodyComponent, selector: "anu-card-body" }, { kind: "component", type: i4.CardFooterComponent, selector: "anu-card-footer" }, { kind: "component", type: i5.CollapsibleComponent, selector: "anu-collapsible", inputs: ["collapsed", "hamBurgerClassNames", "isDropdownStyle"], outputs: ["changed"] }, { kind: "component", type: i5.CollapsibleHeaderComponent, selector: "anu-collapsible-header" }, { kind: "component", type: i5.CollapsibleContentComponent, selector: "anu-collapsible-content" }, { kind: "component", type: i6.CodeBlockComponent, selector: "anu-code-block", inputs: ["source", "language", "enableEdit"], outputs: ["changed", "sourceModalOpenStatusChanged"] }, { kind: "component", type: i7.ModalComponent, selector: "anu-modal", inputs: ["opened", "title", "okLabel", "cancelLabel", "enableOk", "enableCancel", "enableClose"], outputs: ["okClick", "cancelClick"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-sitemap', template: "<div class=\"flex-container center\">\r\n    <div class=\"container\">\r\n        <div class=\"row\">\r\n            <!-- Current Sitemap Urls -->\r\n            <anu-card class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"loadSitemap($event)\">Load sitemap.xml</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible class=\"spacing-vertical\" *ngIf=\"sitemapInfo || sitemap\"\r\n                        [collapsed]=\"currentSitemapCollapsed\" [hamBurgerClassNames]=\"['size-md']\"\r\n                        [isDropdownStyle]=\"true\" (changed)=\"currentSitemapCollapsed = !currentSitemapCollapsed\">\r\n                        <anu-collapsible-header>Current Sitemap</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <h3 *ngIf=\"sitemapInfo\">Sitemap was last updated on:\r\n                                <strong>{{sitemapInfo.updated}}</strong>\r\n                            </h3>\r\n                            <ol *ngIf=\"sitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of sitemap.urlset.url\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, sitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n            <!-- New Urls to be added -->\r\n            <anu-card *ngIf=\"sitemap\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"checkNewUrls($event)\">Check for new Urls</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newUrls\" class=\"spacing-vertical\" [collapsed]=\"checkNewUrlsCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"checkNewUrlsCollapsed = !checkNewUrlsCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">Sitemap new Urls</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <ol *ngIf=\"newUrls?.length\">\r\n                                <li *ngFor=\"let url of newUrls\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <p *ngIf=\"!newUrls?.length\" class=\"warning\">No new urls available</p>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n\r\n            <!-- Preview Merged Urls -->\r\n            <anu-card *ngIf=\"newUrls?.length\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"previewSitemap($event)\">Preview sitemap.xml (Ready to update)</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newSitemap\" class=\"spacing-vertical\" [collapsed]=\"previewCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"previewCollapsed = !previewCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">New Sitemap (Ready to\r\n                            update)</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <div class=\"row\">\r\n                                <span class=\"spacing-half spacing-around\"><small><strong>LEGENDS:</strong>\r\n                                    </small></span>\r\n                                <span class=\"spacing-half spacing-around\"><small>No change</small></span>\r\n                                <span class=\"spacing-half spacing-around success\"><small>Added</small></span>\r\n                                <span class=\"spacing-half spacing-around warning\"><small>Updated</small></span>\r\n                            </div>\r\n                            <ol *ngIf=\"newSitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of newSitemap.urlset.url\" [class.success]=\"url.status === true\"\r\n                                    [class.warning]=\"url.status === false\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, newSitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n                <anu-card-footer *ngIf=\"newSitemap\">\r\n                    <a href=\"#\" class=\"btn btn-primary\" (click)=\"saveSitemap($event)\">Save</a>\r\n                </anu-card-footer>\r\n            </anu-card>\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n<anu-modal [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"false\" [okLabel]=\"'Ok'\"\r\n    [opened]=\"showXmlModal\" [title]=\"'XML view of sitemap'\" (cancelClick)=\"xmlModalClosed()\">\r\n\r\n    <anu-code-block class=\"col-12\" [enableEdit]='false' [language]=\"'xml'\" [source]=\"sitemapXmlStr\">\r\n    </anu-code-block>\r\n\r\n</anu-modal>\r\n" }]
        }], ctorParameters: function () { return [{ type: i2.UtilsService }, { type: SitemapService }]; }, propDecorators: { sitemap: [{
                type: Input
            }], sitemapInfo: [{
                type: Input
            }], newUrls: [{
                type: Input
            }], newSitemap: [{
                type: Input
            }], loadSitemapClicked: [{
                type: Output
            }], saveClicked: [{
                type: Output
            }], previewClicked: [{
                type: Output
            }], checkNewUrlsClicked: [{
                type: Output
            }] } });

class FireStorageModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, declarations: [SitemapComponent], imports: [CommonModule,
            CardModule,
            CollapsibleModule,
            CodeBlockModule,
            ModalModule], exports: [SitemapComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, imports: [CommonModule,
            CardModule,
            CollapsibleModule,
            CodeBlockModule,
            ModalModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SitemapComponent],
                    providers: [],
                    imports: [
                        CommonModule,
                        CardModule,
                        CollapsibleModule,
                        CodeBlockModule,
                        ModalModule,
                    ],
                    exports: [SitemapComponent],
                }]
        }] });

class ImageFileInfo {
    constructor(imageFIle = null) {
        this.name = '';
        this.fullPath = '';
        this.downloadUrl = '';
        if (imageFIle) {
            this.name = imageFIle.name || '';
            this.fullPath = imageFIle.fullPath || '';
            this.downloadUrl = imageFIle.downloadUrl || '';
        }
    }
}

;
;
;
;

class FireStorageImageService {
    constructor(fireCommonService) {
        this.fireCommonService = fireCommonService;
        this.baseStoreUrl = '';
        this.baseStoreUrl = this.fireCommonService.firebaseConfig.storage.baseStoreUrl;
    }
    buildImageUrl(filePath, userId = '') {
        return (this.baseStoreUrl +
            '/' +
            (userId ? `${userId}/${filePath}` : '' + filePath));
    }
    async validateImage(imageData) {
        if (!imageData)
            return 'Empty Image';
        const { maxKBs } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        // Type Check
        if (imageData.type.indexOf('image/') < 0) {
            return `Not a valid image file. Please try uploading a valid jpg/gif/png image file.`;
        }
        //Size Check
        if (imageData.size > maxKBs * 1024) {
            return `Image size exceeds the limit of ${maxKBs}KBs`;
        }
        // Dimension Check.
        return await this.validateImageDimension(imageData);
    }
    async validateImageDimension(imageData) {
        const { maxWidth, maxHeight, minWidth, minHeight } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        var reader = new FileReader();
        //Read the contents of Image File.
        reader.readAsDataURL(imageData);
        const promise = new Promise((resolve, reject) => {
            reader.onload = (e) => {
                //Initiate the JavaScript Image object.
                const image = new Image();
                //Set the Base64 string return from FileReader as source.
                image.src = e.target.result;
                image.onload = () => {
                    // Natural size is the actual image size regardless of rendering.
                    // The 'normal' `width`/`height` are for the **rendered** size.
                    const width = image.naturalWidth;
                    const height = image.naturalHeight;
                    if (width > maxWidth ||
                        minWidth < minWidth ||
                        maxHeight > maxHeight ||
                        minHeight < minHeight) {
                        resolve(`Image dimensions are ${width}px X ${height}px and does not meet the requirement. Allowed width = ${minWidth}px to ${maxWidth}px and allowed height = ${minHeight}px to ${maxHeight}px`);
                    }
                    else {
                        resolve('');
                    }
                };
                // Reject promise on error
                image.onerror = (error) => {
                    reject('Error loading Image');
                };
            };
        });
        return promise;
    }
    async uploadImage(filePath, imageData, overWrite = false, userId = '', isBas64 = false) {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(filePath, userId);
        const fileRef = ref(fireStorage, fileUrl);
        // If exists
        if (!overWrite) {
            try {
                const isExists = await getDownloadURL(fileRef);
                if (isExists) {
                    throw new Error('Image already exists -' + filePath);
                }
            }
            catch (error) {
                if (error.code !== 'storage/object-not-found') {
                    throw error;
                }
            }
        }
        try {
            if (isBas64) {
                imageData = await this.compressBase64ToJpeg(imageData);
            }
            const uploadResult = await uploadBytes(fileRef, imageData);
            const downloadUrl = await this.getImageUrl(filePath, userId);
            const imageFileInfo = {
                name: uploadResult.ref.name,
                fullPath: uploadResult.ref.fullPath,
                downloadUrl,
            };
            return imageFileInfo;
        }
        catch (error) {
            throw error;
        }
    }
    async getImageUrl(filePath, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(filePath, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            const url = await getDownloadURL(fileRef);
            return url;
        }
        catch (error) {
            throw error;
        }
    }
    async deleteImage(filePath, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(filePath, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            return await deleteObject(fileRef);
        }
        catch (error) {
            throw error;
        }
    }
    async getImagesList(filePath, pageSize = 10, nextPageToken = null, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const lookinFolder = this.buildImageUrl(filePath, userId);
        const listRef = ref(fireStorage, lookinFolder);
        try {
            const listOptions = { maxResults: pageSize };
            if (nextPageToken)
                listOptions.pageToken = nextPageToken;
            const imageList = await list(listRef, listOptions);
            const imageFileInfoList = {
                imageFiles: imageList.items.map((img) => ({
                    name: img.name,
                    fullPath: img.fullPath,
                    downloadUrl: '',
                })),
                nextPageToken: imageList.nextPageToken,
            };
            return imageFileInfoList;
        }
        catch (error) {
            throw error;
        }
    }
    async imageExists(filePath, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(filePath, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            const url = await getDownloadURL(fileRef);
            return !!url;
        }
        catch (error) {
            if (error.code !== 'storage/object-not-found') {
                throw error;
            }
            else {
                return false;
            }
        }
    }
    async compressBase64ToJpeg(base64Image) {
        const { maxWidth } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        return new Promise((resolve, reject) => {
            // Convert base64 to blob
            const blob = this.dataURItoBlob(base64Image, 'image/jpeg');
            const compressOptions = {
                strict: true,
                checkOrientation: true,
                width: maxWidth,
                height: maxWidth / 2,
                maxWidth: maxWidth,
                maxHeight: maxWidth / 2,
                resize: 'cover',
                convertTypes: 'image/jpg',
                quality: 0.7,
                success: (compressedBlob) => {
                    // Handle the compressed image blob
                    resolve(compressedBlob);
                },
                error: (error) => {
                    reject(`Image compression error:${error.message}`);
                },
            };
            // Create an image compressor instance
            new Compressor(blob, compressOptions);
        });
    }
    dataURItoBlob(dataURI, type) {
        const byteString = atob(dataURI);
        const arrayBuffer = new ArrayBuffer(byteString.length);
        const uint8Array = new Uint8Array(arrayBuffer);
        for (let i = 0; i < byteString.length; i++) {
            uint8Array[i] = byteString.charCodeAt(i);
        }
        return new Blob([uint8Array], { type });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, deps: [{ token: i1.FireCommonService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }]; } });

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { FireStorageImageService, FireStorageModule, FireStorageSitemapService, ImageFileInfo, SitemapComponent, SitemapService, defaultSitemapXmlStr, sitemapFileName };
//# sourceMappingURL=annuadvent-ngx-tools-fire-storage.mjs.map
