import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, Injectable, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i3 from '@annuadvent/ngx-common-ui/collapsible';
import { CollapsibleModule } from '@annuadvent/ngx-common-ui/collapsible';
import * as i4 from '@annuadvent/ngx-common-ui/spinner';
import { SpinnerModule } from '@annuadvent/ngx-common-ui/spinner';
import { Configuration, OpenAIApi, CreateImageRequestSizeEnum, CreateImageRequestResponseFormatEnum } from 'openai';

var OpenaiPromptTypeEnum;
(function (OpenaiPromptTypeEnum) {
    OpenaiPromptTypeEnum["keywords"] = "keywords";
    OpenaiPromptTypeEnum["subtopics"] = "subtopics";
    OpenaiPromptTypeEnum["questions"] = "questions";
    OpenaiPromptTypeEnum["description"] = "description";
    OpenaiPromptTypeEnum["content"] = "content";
})(OpenaiPromptTypeEnum || (OpenaiPromptTypeEnum = {}));
;

class OpenaiFormComponent {
    constructor() {
        this.prompts = [];
        this.selectedPromptText = '';
        this.showHistory = true;
        this.goClicked = new EventEmitter();
        this.currentPrompt = '';
        this.showPrompts = false;
        this.selectedResultType = 'mdText';
        this.promptTypes = Object.entries(OpenaiPromptTypeEnum).map((pt) => ({
            key: pt[0],
            value: pt[1],
        }));
        this.selectedPromptType = OpenaiPromptTypeEnum.content;
    }
    ngOnInit() {
        this.setSelectedPrompt();
    }
    ngOnChanges(changes) {
        this.setSelectedPrompt();
    }
    setSelectedPrompt() {
        this.selectedPrompt = this.findPrompt(this.selectedPromptText);
        this.selectedPromptType = this.selectedPrompt?.promptType || OpenaiPromptTypeEnum.content;
    }
    promptListChanged() {
        this.setSelectedPrompt();
    }
    goBtnClick(event) {
        event.preventDefault();
        if (!this.currentPrompt.trim())
            return;
        if (!this.findPrompt(this.currentPrompt)) {
            this.prompts.push({
                prompt: this.currentPrompt,
                promptType: this.selectedPromptType,
                message: { mdText: '', htmlText: '', jsonText: '' },
            });
            this.selectedPromptText = this.currentPrompt;
            this.selectedPrompt = this.findPrompt(this.selectedPromptText);
            this.currentPrompt = '';
            this.selectedPromptType = OpenaiPromptTypeEnum.content;
            this.goClicked.emit(this.prompts);
        }
    }
    findPrompt(promptStr) {
        return this.prompts.find((p) => p.prompt === promptStr);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: OpenaiFormComponent, selector: "anu-openai-form", inputs: { prompts: "prompts", selectedPromptText: "selectedPromptText", showHistory: "showHistory" }, outputs: { goClicked: "goClicked" }, usesOnChanges: true, ngImport: i0, template: "<form class=\"container disable-select\">\r\n\r\n    <div class=\"input-container row nowrap\">\r\n        <select class=\"prompt-types\" name=\"prompt-types\" [(ngModel)]=\"selectedPromptType\">\r\n            <option [value]=\"optType.value\" *ngFor=\"let optType of promptTypes\">{{optType.key}}</option>\r\n        </select>\r\n        <input name=\"openaiPrompt\" type=\"text\" placeholder=\"Write your prompt here\" [(ngModel)]=\"currentPrompt\" />\r\n        <a href=\"javascript:void(0)\" class=\"btn primary\" (click)=\"goBtnClick($event)\">\u2315</a>\r\n    </div>\r\n\r\n    <div class=\"row\" *ngIf=\"showHistory\">\r\n        <anu-collapsible [collapsed]=\"false\" class=\"col-12 spacing-around-vertical\" [hamBurgerClassNames]=\"['size-sm']\" [isDropdownStyle]=\"true\">\r\n            <anu-collapsible-header>\r\n                Prompts History\r\n            </anu-collapsible-header>\r\n            <anu-collapsible-content class=\"row\">\r\n                <div class=\"col-6\">\r\n                    <select name=\"prompt-list\" [(ngModel)]=\"selectedPromptText\" (ngModelChange)=\"promptListChanged()\">\r\n                        <option [ngValue]=\"''\">Select..</option>\r\n                        <option [ngValue]=\"prompt.prompt\" *ngFor=\"let prompt of prompts\">{{prompt.prompt}}</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-6\">\r\n                    <select name=\"result-types\" [(ngModel)]=\"selectedResultType\">\r\n                        <option value=\"mdText\">Markdown</option>\r\n                        <option value=\"htmlText\">HTML</option>\r\n                        <option value=\"jsonText\">JSON</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-12\">\r\n                    <textarea readonly>{{selectedPrompt?.message[selectedResultType]}}</textarea>\r\n                </div>\r\n            </anu-collapsible-content>\r\n        </anu-collapsible>\r\n    </div>\r\n</form>\r\n", styles: [":host{display:flex}:host input[type=text]{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}:host .btn{border-top-left-radius:0;border-bottom-left-radius:0;font-size:2rem;color:var(--anu-accent-deep-light);margin-left:-2px;padding:0rem 1.5rem}:host .prompt-types{max-width:10rem}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i3.CollapsibleComponent, selector: "anu-collapsible", inputs: ["collapsed", "hamBurgerClassNames", "isDropdownStyle"], outputs: ["changed"] }, { kind: "component", type: i3.CollapsibleHeaderComponent, selector: "anu-collapsible-header" }, { kind: "component", type: i3.CollapsibleContentComponent, selector: "anu-collapsible-content" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-openai-form', template: "<form class=\"container disable-select\">\r\n\r\n    <div class=\"input-container row nowrap\">\r\n        <select class=\"prompt-types\" name=\"prompt-types\" [(ngModel)]=\"selectedPromptType\">\r\n            <option [value]=\"optType.value\" *ngFor=\"let optType of promptTypes\">{{optType.key}}</option>\r\n        </select>\r\n        <input name=\"openaiPrompt\" type=\"text\" placeholder=\"Write your prompt here\" [(ngModel)]=\"currentPrompt\" />\r\n        <a href=\"javascript:void(0)\" class=\"btn primary\" (click)=\"goBtnClick($event)\">\u2315</a>\r\n    </div>\r\n\r\n    <div class=\"row\" *ngIf=\"showHistory\">\r\n        <anu-collapsible [collapsed]=\"false\" class=\"col-12 spacing-around-vertical\" [hamBurgerClassNames]=\"['size-sm']\" [isDropdownStyle]=\"true\">\r\n            <anu-collapsible-header>\r\n                Prompts History\r\n            </anu-collapsible-header>\r\n            <anu-collapsible-content class=\"row\">\r\n                <div class=\"col-6\">\r\n                    <select name=\"prompt-list\" [(ngModel)]=\"selectedPromptText\" (ngModelChange)=\"promptListChanged()\">\r\n                        <option [ngValue]=\"''\">Select..</option>\r\n                        <option [ngValue]=\"prompt.prompt\" *ngFor=\"let prompt of prompts\">{{prompt.prompt}}</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-6\">\r\n                    <select name=\"result-types\" [(ngModel)]=\"selectedResultType\">\r\n                        <option value=\"mdText\">Markdown</option>\r\n                        <option value=\"htmlText\">HTML</option>\r\n                        <option value=\"jsonText\">JSON</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-12\">\r\n                    <textarea readonly>{{selectedPrompt?.message[selectedResultType]}}</textarea>\r\n                </div>\r\n            </anu-collapsible-content>\r\n        </anu-collapsible>\r\n    </div>\r\n</form>\r\n", styles: [":host{display:flex}:host input[type=text]{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}:host .btn{border-top-left-radius:0;border-bottom-left-radius:0;font-size:2rem;color:var(--anu-accent-deep-light);margin-left:-2px;padding:0rem 1.5rem}:host .prompt-types{max-width:10rem}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { prompts: [{
                type: Input
            }], selectedPromptText: [{
                type: Input
            }], showHistory: [{
                type: Input
            }], goClicked: [{
                type: Output
            }] } });

;
var OpenaiImageSize;
(function (OpenaiImageSize) {
    OpenaiImageSize["_256x256"] = "256x256";
    OpenaiImageSize["_512x512"] = "512x512";
    OpenaiImageSize["_1024x1024"] = "1024x1024";
})(OpenaiImageSize || (OpenaiImageSize = {}));
;
;
;

class OpenaiService {
    constructor() { }
    initOpenai(openaiConfig) {
        if (!openaiConfig || !openaiConfig.apiKey || !openaiConfig.organization)
            throw new Error('Invalid openai configuration.');
        this.openaiConfig = { ...openaiConfig };
        const { apiKey, organization } = this.openaiConfig;
        const configuration = new Configuration({
            organization,
            apiKey,
        });
        delete configuration.baseOptions.headers['User-Agent'];
        this.openAi = new OpenAIApi(configuration);
    }
    async getChatResponse(prompts) {
        if (!this.openAi)
            throw new Error('Openai is not initialzed. Use initOpenai(openaiConfig) to initialize');
        if (!prompts || !prompts.length)
            throw new Error('Not a valid Prompt. Provide one or more prompts in an array of strings.');
        const messages = prompts.map((p) => ({ role: 'user', content: p }));
        const req = {
            model: 'gpt-3.5-turbo',
            messages,
            temperature: 0.7,
            n: 1,
        };
        const response = await this.openAi.createChatCompletion(req);
        const resultMessages = response.data?.choices || [];
        const msgContents = resultMessages.map((rmChoices) => rmChoices.message?.content);
        return msgContents.join('\n');
    }
    async getImagetResponse(promptText, imagesCount = 1, imageSize) {
        if (!this.openAi)
            throw new Error('Openai is not initialzed. Use initOpenai(openaiConfig) to initialize');
        if (!promptText)
            throw new Error('Not a valid Image Prompt.');
        const req = {
            prompt: promptText,
            n: imagesCount || 1,
            size: imageSize || CreateImageRequestSizeEnum._1024x1024,
            response_format: CreateImageRequestResponseFormatEnum.B64Json,
        };
        const response = await this.openAi.createImage(req);
        const imagesData = response.data?.data || [];
        const base64Images = imagesData.map((data) => data.b64_json || '');
        return base64Images;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class OpenaiImageFormComponent {
    constructor(openaiService) {
        this.openaiService = openaiService;
        this.imagePromptText = '';
        this.imageFileName = '';
        this.imageGenerated = new EventEmitter();
        this.generatedBase64Image = '';
        this.savedImageUrl = '';
        this.loading = false;
        this.errorMsg = '';
    }
    async generateImage() {
        if (!this.imagePromptText.trim())
            return '';
        this.startLoading();
        try {
            [this.generatedBase64Image] = await this.openaiService.getImagetResponse(this.imagePromptText, 1, OpenaiImageSize._1024x1024);
            this.stopLoading();
            this.imageGenerated.emit(this.generatedBase64Image);
            return this.generatedBase64Image;
        }
        catch (err) {
            this.generatedBase64Image = '';
            this.stopLoading(err?.message);
            this.imageGenerated.emit('');
            return '';
        }
    }
    startLoading() {
        this.loading = true;
        this.errorMsg = '';
    }
    stopLoading(err = '') {
        this.loading = false;
        this.errorMsg = err;
    }
    uploadImage() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiImageFormComponent, deps: [{ token: OpenaiService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: OpenaiImageFormComponent, selector: "anu-openai-image-form", inputs: { imagePromptText: "imagePromptText", imageFileName: "imageFileName" }, outputs: { imageGenerated: "imageGenerated" }, ngImport: i0, template: "<form class=\"container relative disable-select\">\r\n    <label>Image Prompt</label>\r\n    <input type=\"text\" [(ngModel)]=\"imagePromptText\" name=\"imagePromptText\" />\r\n    <label>Image file name to save generated image<small class=\"error\">* Any image with this filename will be\r\n            overwritten in your image library.</small></label>\r\n    <input type=\"text\" [(ngModel)]=\"imageFileName\" name=\"imageFileName\" />\r\n    <div *ngIf=\"!!generatedBase64Image\" class=\"row\">\r\n        <label>Generated Image <a class=\"primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generatedBase64Image = ''\">Clear</a></label>\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"'data:image/image/jpg;base64,'+ generatedBase64Image\" />\r\n    </div>\r\n    <div *ngIf=\"savedImageUrl\" class=\"row\">\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"savedImageUrl\" />\r\n    </div>\r\n\r\n    <p *ngIf=\"errorMsg\">{{errorMsg}}</p>\r\n    <div class=\"row spacing\">\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generateImage()\">Generate</a></div>\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\" (click)=\"uploadImage()\">Upload</a>\r\n        </div>\r\n    </div>\r\n    <anu-spinner [show]=\"loading\"></anu-spinner>\r\n</form>\r\n", styles: [":host .oif_image{width:100%}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i4.SpinnerComponent, selector: "anu-spinner", inputs: ["show", "fullscreen", "static", "size", "theme", "speed", "mode"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiImageFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-openai-image-form', template: "<form class=\"container relative disable-select\">\r\n    <label>Image Prompt</label>\r\n    <input type=\"text\" [(ngModel)]=\"imagePromptText\" name=\"imagePromptText\" />\r\n    <label>Image file name to save generated image<small class=\"error\">* Any image with this filename will be\r\n            overwritten in your image library.</small></label>\r\n    <input type=\"text\" [(ngModel)]=\"imageFileName\" name=\"imageFileName\" />\r\n    <div *ngIf=\"!!generatedBase64Image\" class=\"row\">\r\n        <label>Generated Image <a class=\"primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generatedBase64Image = ''\">Clear</a></label>\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"'data:image/image/jpg;base64,'+ generatedBase64Image\" />\r\n    </div>\r\n    <div *ngIf=\"savedImageUrl\" class=\"row\">\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"savedImageUrl\" />\r\n    </div>\r\n\r\n    <p *ngIf=\"errorMsg\">{{errorMsg}}</p>\r\n    <div class=\"row spacing\">\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generateImage()\">Generate</a></div>\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\" (click)=\"uploadImage()\">Upload</a>\r\n        </div>\r\n    </div>\r\n    <anu-spinner [show]=\"loading\"></anu-spinner>\r\n</form>\r\n", styles: [":host .oif_image{width:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: OpenaiService }]; }, propDecorators: { imagePromptText: [{
                type: Input
            }], imageFileName: [{
                type: Input
            }], imageGenerated: [{
                type: Output
            }] } });

class OpenaiModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, declarations: [OpenaiFormComponent, OpenaiImageFormComponent], imports: [CommonModule,
            FormsModule,
            CollapsibleModule,
            SpinnerModule], exports: [OpenaiFormComponent, OpenaiImageFormComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, imports: [CommonModule,
            FormsModule,
            CollapsibleModule,
            SpinnerModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [OpenaiFormComponent, OpenaiImageFormComponent],
                    providers: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        CollapsibleModule,
                        SpinnerModule,
                    ],
                    exports: [OpenaiFormComponent, OpenaiImageFormComponent],
                }]
        }] });

const OPENAI_ID_PHRASES = ['AI model', 'As an AI language model'];

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { OPENAI_ID_PHRASES, OpenaiFormComponent, OpenaiImageFormComponent, OpenaiImageSize, OpenaiModule, OpenaiPromptTypeEnum, OpenaiService };
//# sourceMappingURL=annuadvent-ngx-tools-openai.mjs.map
