import { HttpClient } from '@angular/common/http';
import { Sitemap, SitemapItem, SitemapResponse } from '../interfaces/fire-storage-sitemap.interface';
import { UtilsService } from '@annuadvent/ngx-core/utils';
import { AppConfigService } from '@annuadvent/ngx-core/app-config';
import { FireStorageSitemapService } from './fire-storage-sitemap.service';
import * as i0 from "@angular/core";
export declare class SitemapService {
    private appConfigService;
    private utilsSvc;
    private httpClient;
    private sitemapFireSvc;
    constructor(appConfigService: AppConfigService, utilsSvc: UtilsService, httpClient: HttpClient, sitemapFireSvc: FireStorageSitemapService);
    /**
     * Reads the sitemap.xml
     * @date 2/21/2023 - 11:35:49 PM
     *
     * @public
     * @async
     * @returns {Promise<SitemapResponse>}
     */
    getSitemapResponse(): Promise<SitemapResponse>;
    /**
     * Saves both sitemap.xml to firebase storage
     * @date 2/28/2023 - 11:13:44 PM
     *
     * @public
     * @async
     * @param {Sitemap} sitemapJson
     * @returns {Promise<boolean>}
     */
    saveSitemap(sitemapJson: Sitemap): Promise<boolean>;
    /**
     * Appends Urls to existing sitemap json.
     * @date 2/22/2023 - 1:35:03 AM
     *
     * @public
     * @param {Array<SitemapItem>} urls
     * @param {Sitemap} sitemap
     * @returns {Sitemap}
     */
    addUrlsToSitemapJson(urls: Array<SitemapItem>, sitemap: Sitemap): Sitemap;
    /**
     * Converts json sitemap to xml sitemap string.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {Sitemap} sitemap
     * @returns {string}
     */
    jsonToXmlSitemap(sitemap: Sitemap): string;
    /**
     * Converts xml sitemap to json sitemap.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {xmlStr} string
     * @returns {Sitemap}
     */
    xmlToJsonSitemap(xmlStr?: string): Sitemap;
    getLastUpdatedFromSitemap(sitemap: Sitemap): string;
    private prepareSitemapResponse;
    static ɵfac: i0.ɵɵFactoryDeclaration<SitemapService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SitemapService>;
}
